//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Model/Mask/MasksSet.h
//! @brief     Defines class MasksSet.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_MODEL_MASK_MASKSSET_H
#define BORNAGAIN_GUI_MODEL_MASK_MASKSSET_H

#include "Base/Types/VectorWC.h"
#include "GUI/Model/Mask/MaskItems.h"
#include <QModelIndex>
#include <QXmlStreamWriter>

class MessageService;
class RegionOfInterestItem;

//! Container holding various masks as children

class MasksSet : public QObject, public VectorWC<MaskItem> {
    Q_OBJECT
public:
    MasksSet();
    ~MasksSet();

    //! Can be nullptr.
    RegionOfInterestItem* regionOfInterestItem() const;

    void writeTo(QXmlStreamWriter* w) const;
    void readFrom(QXmlStreamReader* r, MessageService* messageService = nullptr);

    void updateMaskNames();

    const QModelIndex rootIndex;

signals:
    void setChanged() const;
    void currentModified() const;
};

#endif // BORNAGAIN_GUI_MODEL_MASK_MASKSSET_H
