//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/Data/MasksQListView.cpp
//! @brief     Implements class MasksQListView.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2021
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "GUI/View/Data/MasksQListView.h"
#include "GUI/Model/Mask/MasksQModel.h"
#include "GUI/Model/Mask/MasksSet.h"
#include "GUI/Model/Project/ProjectDocument.h"
#include "GUI/View/Widget/ListItemDelegate.h"

MasksQListView::MasksQListView(MasksQModel* model)
{
    setMinimumWidth(200);
    setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Expanding);
    setSelectionMode(QAbstractItemView::NoSelection);
    setItemDelegate(new ListItemDelegate(this));
    setModel(model);

    connect(this, &QListView::clicked, [this, set = model->set()](const QModelIndex& qi) {
        set->setCurrentIndex(qi.row());
        emit set->setChanged();
    });

    disconnect(model->set(), &MasksSet::setChanged, nullptr, nullptr);
    connect(model->set(), &MasksSet::setChanged, [this, set = model->set()] {
        setCurrentIndex(this->model()->index(set->currentIndex(), 0));
        repaint();
    });
}
